#[repr(u32)]pub enum CbReason {
Show 72 variants
ValueChange = 1,
Stmt = 2,
Force = 3,
Release = 4,
AtStartOfSimTime = 5,
ReadWriteSynch = 6,
ReadOnlySynch = 7,
NextSimTime = 8,
AfterDelay = 9,
EndOfCompile = 10,
StartOfSimulation = 11,
EndOfSimulation = 12,
Error = 13,
TchkViolation = 14,
StartOfSave = 15,
EndOfSave = 16,
StartOfRestart = 17,
EndOfRestart = 18,
StartOfReset = 19,
EndOfReset = 20,
EnterInteractive = 21,
ExitInteractive = 22,
InteractiveScopeChange = 23,
UnresolvedSystf = 24,
PLIError = 28,
Assign = 25,
Deassign = 26,
Disable = 27,
Signal = 29,
NBASynch = 30,
AtEndOfSimTime = 31,
StartOfThread = 600,
EndOfThread = 601,
EnterThread = 602,
StartOfFrame = 603,
EndOfFrame = 604,
SizeChange = 605,
AssertionStart = 606,
AssertionSuccess = 607,
AssertionFailure = 608,
AssertionStepSuccess = 609,
AssertionStepFailure = 610,
AssertionDisable = 611,
AssertionEnable = 612,
AssertionReset = 613,
AssertionKill = 614,
AssertionSysInitialized = 615,
AssertionSysOn = 616,
AssertionSysOff = 617,
AssertionSysEnd = 618,
AssertionSysReset = 619,
AssertionVacuousSuccess = 657,
AssertionDisabledEvaluation = 658,
AssertionSysLock = 659,
AssertionSysUnlock = 660,
AssertionLock = 661,
AssertionUnlock = 662,
AssertionEnablePassAction = 645,
AssertionEnableFailAction = 646,
AssertionDisablePassAction = 647,
AssertionDisableFailAction = 648,
AssertionEnableNonvacuousAction = 649,
AssertionDisableVacuousAction = 650,
AssertionSysEnablePassAction = 651,
AssertionSysEnableFailAction = 652,
AssertionSysDisablePassAction = 653,
AssertionSysDisableFailAction = 654,
AssertionSysEnableNonvacuousAction = 655,
AssertionSysDisableVacuousAction = 656,
CreateObj = 700,
ReclaimObj = 701,
EndOfObject = 702,
}Expand description
VPI callback reasons used when registering simulator callbacks.
These values map directly to vpi_sys::cb* constants.
Variants
ValueChange = 1
Callback on value change.
Stmt = 2
Callback on statement execution.
Force = 3
Callback on force.
Release = 4
Callback on release.
AtStartOfSimTime = 5
Callback at the start of the current simulation time.
ReadWriteSynch = 6
Callback during the read-write synchronization phase.
ReadOnlySynch = 7
Callback during the read-only synchronization phase.
NextSimTime = 8
Callback at the next simulation time.
AfterDelay = 9
Callback after a delay.
EndOfCompile = 10
Callback at the end of compilation.
StartOfSimulation = 11
Callback at the start of simulation.
EndOfSimulation = 12
Callback at the end of simulation.
Error = 13
Callback on error.
TchkViolation = 14
Callback on timing-check violation.
StartOfSave = 15
Callback at the start of save.
EndOfSave = 16
Callback at the end of save.
StartOfRestart = 17
Callback at the start of restart.
EndOfRestart = 18
Callback at the end of restart.
StartOfReset = 19
Callback at the start of reset.
EndOfReset = 20
Callback at the end of reset.
EnterInteractive = 21
Callback on entry to interactive mode.
ExitInteractive = 22
Callback on exit from interactive mode.
InteractiveScopeChange = 23
Callback when the interactive scope changes.
UnresolvedSystf = 24
Callback on unresolved system task or function lookup.
PLIError = 28
Callback on PLI error.
Assign = 25
Callback on assignment.
Deassign = 26
Callback on deassignment.
Disable = 27
Callback on disable.
Signal = 29
Callback on signal delivery.
NBASynch = 30
Callback during the NBA synchronization phase.
AtEndOfSimTime = 31
Callback at the end of the current simulation time.
StartOfThread = 600
sv only.Callback on thread creation.
EndOfThread = 601
sv only.Callback on thread termination.
EnterThread = 602
sv only.Callback on thread reentry.
StartOfFrame = 603
sv only.Callback on frame creation.
EndOfFrame = 604
sv only.Callback on frame exit.
SizeChange = 605
sv only.Callback on array variable size change.
AssertionStart = 606
sv only.Assertion start.
AssertionSuccess = 607
sv only.Assertion success.
AssertionFailure = 608
sv only.Assertion failure.
AssertionStepSuccess = 609
sv only.Assertion step success.
AssertionStepFailure = 610
sv only.Assertion step failure.
AssertionDisable = 611
sv only.Assertion disable.
AssertionEnable = 612
sv only.Assertion enable.
AssertionReset = 613
sv only.Assertion reset.
AssertionKill = 614
sv only.Assertion kill.
AssertionSysInitialized = 615
sv only.Assertion system initialization.
AssertionSysOn = 616
sv only.Assertion system on.
AssertionSysOff = 617
sv only.Assertion system off.
AssertionSysEnd = 618
sv only.Assertion system end.
AssertionSysReset = 619
sv only.Assertion system reset.
AssertionVacuousSuccess = 657
sv only.Assertion vacuous success.
AssertionDisabledEvaluation = 658
sv only.Assertion disabled evaluation.
AssertionSysLock = 659
sv only.Assertion system lock.
AssertionSysUnlock = 660
sv only.Assertion system unlock.
AssertionLock = 661
sv only.Assertion lock.
AssertionUnlock = 662
sv only.Assertion unlock.
AssertionEnablePassAction = 645
sv only.Assertion enable pass action.
AssertionEnableFailAction = 646
sv only.Assertion enable fail action.
AssertionDisablePassAction = 647
sv only.Assertion disable pass action.
AssertionDisableFailAction = 648
sv only.Assertion disable fail action.
AssertionEnableNonvacuousAction = 649
sv only.Assertion enable non-vacuous action.
AssertionDisableVacuousAction = 650
sv only.Assertion disable vacuous action.
AssertionSysEnablePassAction = 651
sv only.Assertion system enable pass action.
AssertionSysEnableFailAction = 652
sv only.Assertion system enable fail action.
AssertionSysDisablePassAction = 653
sv only.Assertion system disable pass action.
AssertionSysDisableFailAction = 654
sv only.Assertion system disable fail action.
AssertionSysEnableNonvacuousAction = 655
sv only.Assertion system enable non-vacuous action.
AssertionSysDisableVacuousAction = 656
sv only.Assertion system disable vacuous action.
CreateObj = 700
sv only.Callback on class object creation.
ReclaimObj = 701
sv only.Callback on class object reclamation.
EndOfObject = 702
sv only.Callback on transient object deletion.